@@ -20,18 +20,17 @@
  * along with this package. If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
 
-
-
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include <QMessageBox>
 #include <QProgressBar>
+#include <QTemporaryDir>
 #include <QTimer>
 
 #include <dialog.h>
-#include <mprocess.h>
 #include <version.h>
+#include <cmd.h>
 
 
 namespace Ui {
@@ -52,21 +51,21 @@ public:
     void addGrubArg(const QString &key, const QString &item);
     void addGrubLine(const QString &item);
     void createChrootEnv(QString root);
-    void enableGrubLine(const QString &item);
     void disableGrubLine(const QString &item);
-    void remGrubArg(const QString &key, const QString &item);
+    void enableGrubLine(const QString &item);
     void loadPlymouthThemes();
-    void readGrubCfg();
     void readDefaultGrub();
+    void readGrubCfg();
     void readKernelOpts();
-    void setup();
+    void remGrubArg(const QString &key, const QString &item);
     void sendMouseEvents();
+    void setup();
     void writeDefaultGrub() const;
 
     bool checkInstalled(const QString &package);
     bool checkInstalled(const QStringList &packages);
-    bool installSplash();
     bool inVirtualMachine();
+    bool installSplash();
     bool replaceGrubArg(const QString &key, const QString &item);
 
     int findMenuEntryById(const QString &id) const;
@@ -76,30 +75,32 @@ public slots:
 
 private slots:
     void cleanup();
-    void cmdStart();
     void cmdDone();
+    void cmdStart();
     void procTime();
     void setConnections();
-    void on_buttonApply_clicked();
-    void on_buttonAbout_clicked();
-    void on_buttonHelp_clicked();
-    void on_cb_bootsplash_clicked(bool checked);
+
     void on_btn_bg_file_clicked();
-    void on_rb_detailed_msg_toggled(bool checked);
-    void on_rb_very_detailed_msg_toggled(bool checked);
-    void on_rb_limited_msg_toggled(bool checked);
-    void on_spinBoxTimeout_valueChanged(int val);
-    void on_combo_menu_entry_currentIndexChanged(int index);
-    void on_cb_bootsplash_toggled(bool checked);
-    void on_buttonLog_clicked();
-    void on_combo_theme_activated(int);
-    void on_button_preview_clicked();
-    void on_cb_enable_flatmenus_clicked(bool checked);
-    void on_cb_save_default_clicked();
-    void on_combo_theme_currentIndexChanged(const QString &arg1);
-    void on_cb_grub_theme_toggled(bool checked);
     void on_btn_theme_file_clicked();
+    void on_buttonAbout_clicked();
+    void on_buttonApply_clicked();
+    void on_buttonHelp_clicked();
+    void on_buttonLog_clicked();
+    void on_button_preview_clicked();
+    void on_cb_bootsplash_clicked(bool checked);
+    void on_cb_bootsplash_toggled(bool checked);
+    void on_cb_enable_flatmenus_clicked(bool checked);
+    void on_cb_grub_theme_toggled(bool checked);
+    void on_cb_save_default_clicked();
+    void on_combo_menu_entry_currentIndexChanged(int index);
+    void on_combo_theme_activated(int);
+    void on_combo_theme_currentIndexChanged(const QString &arg1);
     void on_lineEdit_kernel_textEdited();
+    void on_rb_detailed_msg_toggled(bool checked);
+    void on_rb_limited_msg_toggled(bool checked);
+    void on_rb_very_detailed_msg_toggled(bool checked);
+    void on_spinBoxTimeout_valueChanged(int val);
+
 
 protected:
     void keyPressEvent(QKeyEvent* event);
@@ -107,20 +108,22 @@ protected:
 
 private:
     Ui::MainWindow *ui;
-    MProcess proc;
+    Cmd cmd;
     QTimer timer;
 
+    bool grub_installed;
     bool just_installed;
     bool kernel_options_changed;
     bool messages_changed;
     bool options_changed;
     bool splash_changed;
 
-    QStringList grub_cfg;
-    QStringList default_grub;
-    QString kernel_options;
     QString chroot;
+    QString kernel_options;
     QString user;
+    QStringList default_grub;
+    QStringList grub_cfg;
+    QTemporaryDir tmpdir;
 };
 
 
